//------------------------------------------------------------------------------//
//				AXC-PL01_SAMPLE1_OUTPUT Module  V1.20					//
//			CompactFlash CF+ Programmable Logic CARD					//
//					ADTEK SYSTEM SCIENCE CO.,LTD.						//
//				Since 2005/01/13  LAST UPDATE 2005/11/07				//
//						<< S1_OUTPUT U2 >>							//
//------------------------------------------------------------------------------//

//------------------------------------------------------------------------------//
//	Module	C_ -> CompactFlash, L_ ->LocalSignal, P -> PIO Signal			//
//			n  -> Active Low Signal									//
//------------------------------------------------------------------------------//

module S1_OUTPUT

	(	IO_DATA_IO,
		C_DATA_IO,
		IO_DATAOUT_I,
		IO_DATAOUT_EN_I,
		C_DATAOUT_I,
		C_DATAOUT_EN_I,
		L_125GEN,
		IO_DATAIN_O,
		C_DATAIN_O
	);

//-----------------------Inout Signal Definition--------------------------------//

	inout	[13:0]IO_DATA_IO;					// Parallel I/O
											// PIO Side Bus  U2

	inout	[13:0]C_DATA_IO;					// CompactFlash CARD DATA
											// Card Bus  U2

//-----------------------Input Signal Definition--------------------------------//

 	input	[13:0]IO_DATAOUT_I;					// Data Register 
											// OIOւOUTDATA̓
											// U1  U2

	input	[13:0]IO_DATAOUT_EN_I;				// I/O Select Register 
											// U1  U2,U3

	input	[13:0]C_DATAOUT_I;					// CompactFlash DATA o͐M
											// U3  U2

	input	[1:0]C_DATAOUT_EN_I;				// CompactFlash DATA OUT Enable
											// CARD DATA OUT ENABLE
											// U3  MAIN,U2

	input	L_125GEN;							// Write Mode Switch
											// MAIN  U1,U2

//-----------------------Output Signal Definition-------------------------------//

	output	[13:0]IO_DATAIN_O;					// OIO͂DATA
											// U2  U3

	output	[13:0]C_DATAIN_O;					//  CompactFlash DATA Buses 
											// U2  U0,U1



//------------------------------------------------------------------------------//
//	Local Side IN/OUT ؑ֗p											//
// 																//
//		L	:L_125GEN				:Write Mode Switch					//
//		en	:[13:0]IO_DATAOUT_EN_I	:I/O Select Register				//
// 																//
//		I 	:[13:0]IO_DATAOUT_I		:Data Register 					//
//		E 	:[13:0]data_en			:Enable `őI					//
//		IO	:[13:0]IO_DATA_IO		:PIO DATA Buses					//			
// 		D 	:[13:0]IO_DATAIN_O		: DATA Buses					//
// 																//
//	Enable `													//
//	[13:0]data_en =  IO_DATAOUT_EN_I[13:0] OR L_125GEN					//
//																//
//			+-----+-----++------+									//
// 			|  L  |  en ||   E  |									//
//			======+=====++======+									//
//			|  1  |  1  ||   1  |									//
//			+-----+-----++------+									//
//			|  1  |  0  ||   1  |									//
//			+-----+-----++------+									//
//			|  0  |  1  ||   1  |									//
//			+-----+-----++------+									//
//			|  0  |  0  ||   0  |									//
//			+-----+-----++------+									//
// 																//
//	Data Register o											//
// 								+-----+-----++------+-----+			//
// 		E-----+					|  E	 |  I  ||  IO  |  O  |			//
//		      |			 		+=====+=====++======+=====+			//
//		I____|________IO			|  1  |  0  ||   Z  |  X  |			//
//		     |^    |				+-----+-----++------+-----+			//
//		@@@@@  |				|  0  |  1  ||   1  |  1  |			//
//		D____^|____|				+-----+-----++------+-----+			//
//		     _|					|  0  |  0  ||   0  |  0  |			//
// 								+-----+-----++------+-----+			//
//																//
// 																//
//------------------------------------------------------------------------------//

//  Enable `

	wire		data_en[13:0];

	assign	data_en[0]	= IO_DATAOUT_EN_I[0] | L_125GEN ;
	assign	data_en[1]	= IO_DATAOUT_EN_I[1] | L_125GEN ;
	assign	data_en[2]	= IO_DATAOUT_EN_I[2] | L_125GEN ;
	assign	data_en[3]	= IO_DATAOUT_EN_I[3] | L_125GEN ;
	assign	data_en[4]	= IO_DATAOUT_EN_I[4] | L_125GEN ;
	assign	data_en[5]	= IO_DATAOUT_EN_I[5] | L_125GEN ;
	assign	data_en[6]	= IO_DATAOUT_EN_I[6] | L_125GEN ;
	assign	data_en[7]	= IO_DATAOUT_EN_I[7] | L_125GEN ;
	assign	data_en[8]	= IO_DATAOUT_EN_I[8] | L_125GEN ;
	assign	data_en[9]	= IO_DATAOUT_EN_I[9] | L_125GEN ;
	assign	data_en[10]	= IO_DATAOUT_EN_I[10] | L_125GEN ;
	assign	data_en[11]	= IO_DATAOUT_EN_I[11] | L_125GEN ;
	assign	data_en[12]	= IO_DATAOUT_EN_I[12] | L_125GEN ;
	assign	data_en[13]	= IO_DATAOUT_EN_I[13] | L_125GEN ;


//  I/Odata o͒`

	assign	IO_DATA_IO[0]	= (data_en[0])  ?  1'bZ : IO_DATAOUT_I[0] ;
	assign	IO_DATA_IO[1]	= (data_en[1])  ?  1'bZ : IO_DATAOUT_I[1] ;
	assign	IO_DATA_IO[2]	= (data_en[2])  ?  1'bZ : IO_DATAOUT_I[2] ;
	assign	IO_DATA_IO[3]	= (data_en[3])  ?  1'bZ : IO_DATAOUT_I[3] ;
	assign	IO_DATA_IO[4]	= (data_en[4])  ?  1'bZ : IO_DATAOUT_I[4] ;
	assign	IO_DATA_IO[5]	= (data_en[5])  ?  1'bZ : IO_DATAOUT_I[5] ;
	assign	IO_DATA_IO[6]	= (data_en[6])  ?  1'bZ : IO_DATAOUT_I[6] ;
	assign	IO_DATA_IO[7]	= (data_en[7])  ?  1'bZ : IO_DATAOUT_I[7] ;
	assign	IO_DATA_IO[8]	= (data_en[8])  ?  1'bZ : IO_DATAOUT_I[8] ;
	assign	IO_DATA_IO[9]	= (data_en[9])  ?  1'bZ : IO_DATAOUT_I[9] ;
	assign	IO_DATA_IO[10]	= (data_en[10]) ?  1'bZ : IO_DATAOUT_I[10] ;
	assign	IO_DATA_IO[11]	= (data_en[11]) ?  1'bZ : IO_DATAOUT_I[11] ;
	assign	IO_DATA_IO[12]	= (data_en[12]) ?  1'bZ : IO_DATAOUT_I[12] ;
	assign	IO_DATA_IO[13]	= (data_en[13]) ?  1'bZ : IO_DATAOUT_I[13] ;


//  IOdata Ddata ڑ`
	
	assign	IO_DATAIN_O[13:0]	= IO_DATA_IO[13:0];	



//------------------------------------------------------------------------------//
//		CompactFlash CARD DATA IN/OUT ؑ֗p IO Buffer					//
//				I :C_DATAOUT_I		:CompactFlash DATA o͐M			//
//				E :C_DATAOUT_EN_I	:CompactFlash DATA OUT Enable			//
//				IO:C_DATA_IO		:CompactFlash CARD DATA				//			
// 				O :C_DATAIN_O		: CompactFlash DATA Buses			//
// 																//
// 		IOBUFE 													//
// 							+-----+------++------+-----+				//
// 		E-----+				|  E  |	I  ||  IO  |  O  |				//
//		      |			 	======+======++======+=====+				//
//		I____|________IO		|  1  |	X  ||   Z  |  X  |				//
//		     |^    |			+-----+------++------+-----+				//
//		@@@@@  |			|  0  |	1  ||   1  |  1  |				//
//		O____^|____|			+-----+------++------+-----+				//
//		     _|				|  0  |	0  ||   0  |  0  |				//
// 							+-----+------++------+-----+				//
// 																//
//------------------------------------------------------------------------------//


	IOBUFE CIOBUF13(.O(C_DATAIN_O[13]),.IO(C_DATA_IO[13]),.I(C_DATAOUT_I[13]),.E(C_DATAOUT_EN_I[1]));
	IOBUFE CIOBUF12(.O(C_DATAIN_O[12]),.IO(C_DATA_IO[12]),.I(C_DATAOUT_I[12]),.E(C_DATAOUT_EN_I[1]));
	IOBUFE CIOBUF11(.O(C_DATAIN_O[11]),.IO(C_DATA_IO[11]),.I(C_DATAOUT_I[11]),.E(C_DATAOUT_EN_I[1]));
	IOBUFE CIOBUF10(.O(C_DATAIN_O[10]),.IO(C_DATA_IO[10]),.I(C_DATAOUT_I[10]),.E(C_DATAOUT_EN_I[1]));
	IOBUFE CIOBUF9 (.O(C_DATAIN_O[9]), .IO(C_DATA_IO[9]), .I(C_DATAOUT_I[9]), .E(C_DATAOUT_EN_I[1]));
	IOBUFE CIOBUF8 (.O(C_DATAIN_O[8]), .IO(C_DATA_IO[8]), .I(C_DATAOUT_I[8]), .E(C_DATAOUT_EN_I[1]));
	IOBUFE CIOBUF7 (.O(C_DATAIN_O[7]), .IO(C_DATA_IO[7]), .I(C_DATAOUT_I[7]), .E(C_DATAOUT_EN_I[0]));
	IOBUFE CIOBUF6 (.O(C_DATAIN_O[6]), .IO(C_DATA_IO[6]), .I(C_DATAOUT_I[6]), .E(C_DATAOUT_EN_I[0]));
	IOBUFE CIOBUF5 (.O(C_DATAIN_O[5]), .IO(C_DATA_IO[5]), .I(C_DATAOUT_I[5]), .E(C_DATAOUT_EN_I[0]));
	IOBUFE CIOBUF4 (.O(C_DATAIN_O[4]), .IO(C_DATA_IO[4]), .I(C_DATAOUT_I[4]), .E(C_DATAOUT_EN_I[0]));
	IOBUFE CIOBUF3 (.O(C_DATAIN_O[3]), .IO(C_DATA_IO[3]), .I(C_DATAOUT_I[3]), .E(C_DATAOUT_EN_I[0]));
	IOBUFE CIOBUF2 (.O(C_DATAIN_O[2]), .IO(C_DATA_IO[2]), .I(C_DATAOUT_I[2]), .E(C_DATAOUT_EN_I[0]));
	IOBUFE CIOBUF1 (.O(C_DATAIN_O[1]), .IO(C_DATA_IO[1]), .I(C_DATAOUT_I[1]), .E(C_DATAOUT_EN_I[0]));
	IOBUFE CIOBUF0 (.O(C_DATAIN_O[0]), .IO(C_DATA_IO[0]), .I(C_DATAOUT_I[0]), .E(C_DATAOUT_EN_I[0]));


//------------------------------------------------------------------------------//

endmodule


