//------------------------------------------------------------------------------//
//				AXC-PL01_SAMPLE3_IRQIO Module  V1.20					//
//			CompactFlash CF+ Programmable Logic CARD					//
//					ADTEK SYSTEM SCIENCE CO.,LTD.						//
//				Since 2005/01/13  LAST UPDATE 2005/11/07				//
//						<< S3_IRQIO U4 >>							//
//------------------------------------------------------------------------------//	

//------------------------------------------------------------------------------//
//	Module	C_ -> CompactFlash, L_ ->LocalSignal, P -> PIO Signal			//
//			n  -> Active Low Signal									//
//------------------------------------------------------------------------------//

module S3_IRQIO

	(	C_DATA_I,
		IRQ_C_ADR_I,
		CE,
		COR_IRQENB_I,
		IO_DATAIN_I,
		MRST,
		REG_I,
		ENIO_nIOWR_I,
		C_INTRRUPT_O,
		IRQ_IRQST_O,
		IRQSP,
		IRQSP1
	);

//-----------------------Input Signal Definition--------------------------------//

	input	[13:0] C_DATA_I;			//  CompactFlash DATA Buses 			
									// (IO Buffer CompactFlash CARD DATA)
									// U2  U0,U1,U4

	input	[3:0] IRQ_C_ADR_I;			// CompactFlash ADDRESS
									// Card Bus  U0,U1,U3,U4

	input	[2:1] CE;					// CompactFlash ChipEnable "H"Byte/"L"Byte
									// Card Bus @U1,U3,U4

	input	COR_IRQENB_I;				// Configuration Option Register
									// IRQ Enable Bit[3] 200H <- 04H
									// U0  U4

	input	[13:12] IO_DATAIN_I;		// OIO͂DATA
									// U2  U3,U4

	input	MRST;					// RtBM[VZbgM
									// MAIN  U1,U4

	input	REG_I;					// CompactFlash Register Access
									// Card Bus  U0,U1,U3,U4

	input	ENIO_nIOWR_I;				// IOWR Write Enable M
									// MAIN  U1


//-----------------------Output Signal Definition-------------------------------//

     output	C_INTRRUPT_O;				// CompactFlash Intrrupt Request
									// U4  Card Bus
 
	output	[9:8] IRQ_IRQST_O;			// IRQ REGISTER [9:8]
									// U4  U3

	output	[3:2] IRQSP;				// IRQ REGISTER [3:2]
									// U4  U3

	output	[1:0] IRQSP1;				// IRQ REGISTER [1:8]
									// U4  U3

//-----------------------Wire definition----------------------------------------//

	wire		C_INTRRUPT_O;
	wire		[2:1] CE;

//------------------------Register definition-----------------------------------//

	reg		[9:8] IRQ_IRQST_O;
	reg		[1:0] IRQSP1;


//------------------------------------------------------------------------------//
//				IRQ Register (R/W)									//
//				I/Ox[XAhX +8								//
//				Register		= [9:8]IRQ_IRQST_O;					//
//								  [1:0]IRQSP1;						//
//				Register Default 	= 1								//				
// 				Pull Downs		= 0								//
//				Pull Ups	 		= 1								//
// 																//
//------------------------------------------------------------------------------//

// LANZXCompactFlash Specification Revision 1.4 ɏĂ܂B
// ڍׂɂĂ͐发ГłmFB

// INDEX8W	= IRQ Select Register [hANZX
// INDEX8BL	= IRQ Select Register oCgANZXioCgANZXj
// INDEX8BH	= IRQ Select Register oCgANZXioCgANZXj

	wire		INDEX8W;
	assign	INDEX8W = (IRQ_C_ADR_I[3:1]	==	3'b100)
						&&	(CE[2]	==	1'b0);

	wire		INDEX8BL;
	assign	INDEX8BL = (IRQ_C_ADR_I[3:0]	==	4'b1000)
						&&	(CE[2:1]	==	2'b10);

	wire		INDEX8BH;
	assign	INDEX8BH = (IRQ_C_ADR_I[3:0]	==	4'b1001)
						&&	(CE[2:1]	==	2'b10);

//------------------------------------------------------------------------------//

	always @(posedge ENIO_nIOWR_I or posedge MRST) begin

		if (MRST == 1) begin
			IRQSP1[1:0]		<=	2'b11;		   
  			IRQ_IRQST_O[9:8]	<=	2'b11;

		end 	
		
		else if (MRST	== 0) begin					
			
			if (REG_I	== 1'b0) begin

				if (INDEX8W) begin
					IRQSP1[1:0]		<=	C_DATA_I[1:0];
					IRQ_IRQST_O[9:8]	<=	C_DATA_I[9:8];

				end if (INDEX8BL) begin		 
					IRQSP1[1:0]		<=	C_DATA_I[1:0];

  				end if (INDEX8BH) begin 
    					IRQ_IRQST_O[9:8]	<=	C_DATA_I[1:0];						

				end
			end
		end
	end

		
//------------------------------------------------------------------------------//

	wire		d3preset;
	assign	d3preset = IRQSP1[1] | ~IRQ_IRQST_O[9];

	wire		d2preset;
	assign	d2preset = IRQSP1[0] | ~IRQ_IRQST_O[8];


//------------------------------------------------------------------------------//
//		CompactFlash CARD DATA IN/OUT ؑ֗p IO Buffer					//
//			   PRE :PRESET			:CompactFlash DATA o͐M			//
//				C :CLK			:CompactFlash DATA OUT Enable			//
//				D :INPUT			:CompactFlash CARD DATA				//			
// 				Q :OUTPUT			: CompactFlash DATA Buses			//
// 																//
// 		FDP 														//
// 																//
// 	   PRE-----+				+-------+------+------++-----+			//
// 	   	     _|____			|  PRE  |	  C  |   I  ||  Q  |			//
//		    | 	 |			+=======+======+======++=====+			//
//		D___|      |___IO		|   1   |   X  |   X  ||  1  |			//
//		    |      |			+-------+------+------++-----+			//
//		C___|_    |			|   0   |    |   1  ||  1  |			//
//		    |^    |			+-------+------+------++-----+			//
//		    |______| 			|   0   |    |   0  ||  0  |			//
// 							+-------+------+------++-----+			//
// 																//
//------------------------------------------------------------------------------//


	FDP UFD0 ( .Q(IRQSP[3]),
 			 .C(~IO_DATAIN_I[13]),
			 .D(IRQSP1[1]),
			 .PRE(d3preset)
			);

	FDP UFD1 ( .Q(IRQSP[2]),
 			 .C(~IO_DATAIN_I[12]),
			 .D(IRQSP1[0]),
			 .PRE(d2preset)
			);


//------------------------------------------------------------------------------//
//	CompactFlash Intrrupt Request										//
//------------------------------------------------------------------------------//
 
	assign	C_INTRRUPT_O	= ~( ((~IRQSP[3]) | (~IRQSP[2])) & COR_IRQENB_I );


endmodule

